# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x9d\x02\n\rSignupFlowReq\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12-\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x1e.org.couchers.auth.SignupBasic\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .org.couchers.auth.SignupAccount\x12\x34\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\x12\x19\n\x0b\x65mail_token\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12?\n\x1b\x61\x63\x63\x65pt_community_guidelines\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xdd\x01\n\rSignupFlowRes\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12,\n\x08\x61uth_res\x18\x03 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\x12\x12\n\nneed_basic\x18\x04 \x01(\x08\x12\x14\n\x0cneed_account\x18\x05 \x01(\x08\x12\x15\n\rneed_feedback\x18\x06 \x01(\x08\x12\x19\n\x11need_verify_email\x18\x07 \x01(\x08\x12(\n need_accept_community_guidelines\x18\x08 \x01(\x08\"*\n\x0bSignupBasic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"\xe6\x01\n\rSignupAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x01\x12\x0b\n\x03lng\x18\x08 \x01(\x01\x12\x0e\n\x06radius\x18\t \x01(\x01\x12\x11\n\tbirthdate\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12<\n\x0ehosting_status\x18\x05 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x12\n\naccept_tos\x18\n \x01(\x08\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"\x18\n\x08LoginReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"z\n\x08LoginRes\x12\x38\n\tnext_step\x18\x01 \x01(\x0e\x32%.org.couchers.auth.LoginRes.LoginStep\"4\n\tLoginStep\x12\x11\n\rNEED_PASSWORD\x10\x00\x12\x14\n\x10SENT_LOGIN_EMAIL\x10\x01\"2\n\x15\x43ompleteTokenLoginReq\x12\x19\n\x0blogin_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\">\n\x18\x43ompletePasswordResetReq\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"9\n\x15\x43onfirmChangeEmailReq\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"Q\n\x15\x43onfirmChangeEmailRes\x12\x38\n\x05state\x18\x01 \x01(\x0e\x32).org.couchers.auth.EmailConfirmationState\"\xab\x01\n\x0f\x43ontributorForm\x12\r\n\x05ideas\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x01(\t\x12\x12\n\nexperience\x18\x03 \x01(\t\x12\x37\n\ncontribute\x18\x04 \x01(\x0e\x32#.org.couchers.auth.ContributeOption\x12\x17\n\x0f\x63ontribute_ways\x18\x05 \x03(\t\x12\x11\n\texpertise\x18\x06 \x01(\t\".\n\x17\x43onfirmDeleteAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"(\n\x11RecoverAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\".\n\x0eUnsubscribeReq\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"\"\n\x0eUnsubscribeRes\x12\x10\n\x08response\x18\x01 \x01(\t*\xea\x01\n\x16\x45mailConfirmationState\x12$\n EMAIL_CONFIRMATION_STATE_UNKNOWN\x10\x00\x12$\n EMAIL_CONFIRMATION_STATE_SUCCESS\x10\x01\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL\x10\x02\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL\x10\x03*\x87\x01\n\x10\x43ontributeOption\x12!\n\x1d\x43ONTRIBUTE_OPTION_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43ONTRIBUTE_OPTION_YES\x10\x01\x12\x1b\n\x17\x43ONTRIBUTE_OPTION_MAYBE\x10\x02\x12\x18\n\x14\x43ONTRIBUTE_OPTION_NO\x10\x03\x32\xa8\x08\n\x04\x41uth\x12i\n\nSignupFlow\x12 .org.couchers.auth.SignupFlowReq\x1a .org.couchers.auth.SignupFlowRes\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/auth/signup:\x01*\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12\x43\n\x05Login\x12\x1b.org.couchers.auth.LoginReq\x1a\x1b.org.couchers.auth.LoginRes\"\x00\x12\\\n\x12\x43ompleteTokenLogin\x12(.org.couchers.auth.CompleteTokenLoginReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x15\x43ompletePasswordReset\x12+.org.couchers.auth.CompletePasswordResetReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x12\x43onfirmChangeEmail\x12(.org.couchers.auth.ConfirmChangeEmailReq\x1a(.org.couchers.auth.ConfirmChangeEmailRes\"\x00\x12\\\n\x14\x43onfirmDeleteAccount\x12*.org.couchers.auth.ConfirmDeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x0eRecoverAccount\x12$.org.couchers.auth.RecoverAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x0bUnsubscribe\x12!.org.couchers.auth.UnsubscribeReq\x1a!.org.couchers.auth.UnsubscribeRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._loaded_options = None
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._loaded_options = None
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_COMPLETETOKENLOGINREQ'].fields_by_name['login_token']._loaded_options = None
  _globals['_COMPLETETOKENLOGINREQ'].fields_by_name['login_token']._serialized_options = b'\200\265\030\001'
  _globals['_AUTHREQ'].fields_by_name['password']._loaded_options = None
  _globals['_AUTHREQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_COMPLETEPASSWORDRESETREQ'].fields_by_name['password_reset_token']._loaded_options = None
  _globals['_COMPLETEPASSWORDRESETREQ'].fields_by_name['password_reset_token']._serialized_options = b'\200\265\030\001'
  _globals['_CONFIRMCHANGEEMAILREQ'].fields_by_name['change_email_token']._loaded_options = None
  _globals['_CONFIRMCHANGEEMAILREQ'].fields_by_name['change_email_token']._serialized_options = b'\200\265\030\001'
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\200\265\030\001'
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\200\265\030\001'
  _globals['_AUTH']._loaded_options = None
  _globals['_AUTH']._serialized_options = b'\210\265\030\001'
  _globals['_AUTH'].methods_by_name['SignupFlow']._loaded_options = None
  _globals['_AUTH'].methods_by_name['SignupFlow']._serialized_options = b'\202\323\344\223\002\021\"\014/auth/signup:\001*'
  _globals['_EMAILCONFIRMATIONSTATE']._serialized_start=1975
  _globals['_EMAILCONFIRMATIONSTATE']._serialized_end=2209
  _globals['_CONTRIBUTEOPTION']._serialized_start=2212
  _globals['_CONTRIBUTEOPTION']._serialized_end=2347
  _globals['_SIGNUPFLOWREQ']._serialized_start=155
  _globals['_SIGNUPFLOWREQ']._serialized_end=440
  _globals['_SIGNUPFLOWRES']._serialized_start=443
  _globals['_SIGNUPFLOWRES']._serialized_end=664
  _globals['_SIGNUPBASIC']._serialized_start=666
  _globals['_SIGNUPBASIC']._serialized_end=708
  _globals['_SIGNUPTOKENINFOREQ']._serialized_start=710
  _globals['_SIGNUPTOKENINFOREQ']._serialized_end=758
  _globals['_SIGNUPACCOUNT']._serialized_start=761
  _globals['_SIGNUPACCOUNT']._serialized_end=991
  _globals['_USERNAMEVALIDREQ']._serialized_start=993
  _globals['_USERNAMEVALIDREQ']._serialized_end=1029
  _globals['_USERNAMEVALIDRES']._serialized_start=1031
  _globals['_USERNAMEVALIDRES']._serialized_end=1064
  _globals['_LOGINREQ']._serialized_start=1066
  _globals['_LOGINREQ']._serialized_end=1090
  _globals['_LOGINRES']._serialized_start=1092
  _globals['_LOGINRES']._serialized_end=1214
  _globals['_LOGINRES_LOGINSTEP']._serialized_start=1162
  _globals['_LOGINRES_LOGINSTEP']._serialized_end=1214
  _globals['_COMPLETETOKENLOGINREQ']._serialized_start=1216
  _globals['_COMPLETETOKENLOGINREQ']._serialized_end=1266
  _globals['_AUTHREQ']._serialized_start=1268
  _globals['_AUTHREQ']._serialized_end=1340
  _globals['_AUTHRES']._serialized_start=1342
  _globals['_AUTHRES']._serialized_end=1384
  _globals['_RESETPASSWORDREQ']._serialized_start=1386
  _globals['_RESETPASSWORDREQ']._serialized_end=1418
  _globals['_COMPLETEPASSWORDRESETREQ']._serialized_start=1420
  _globals['_COMPLETEPASSWORDRESETREQ']._serialized_end=1482
  _globals['_CONFIRMCHANGEEMAILREQ']._serialized_start=1484
  _globals['_CONFIRMCHANGEEMAILREQ']._serialized_end=1541
  _globals['_CONFIRMCHANGEEMAILRES']._serialized_start=1543
  _globals['_CONFIRMCHANGEEMAILRES']._serialized_end=1624
  _globals['_CONTRIBUTORFORM']._serialized_start=1627
  _globals['_CONTRIBUTORFORM']._serialized_end=1798
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_start=1800
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_end=1846
  _globals['_RECOVERACCOUNTREQ']._serialized_start=1848
  _globals['_RECOVERACCOUNTREQ']._serialized_end=1888
  _globals['_UNSUBSCRIBEREQ']._serialized_start=1890
  _globals['_UNSUBSCRIBEREQ']._serialized_end=1936
  _globals['_UNSUBSCRIBERES']._serialized_start=1938
  _globals['_UNSUBSCRIBERES']._serialized_end=1972
  _globals['_AUTH']._serialized_start=2350
  _globals['_AUTH']._serialized_end=3414
# @@protoc_insertion_point(module_scope)



from couchers.proto import (
    account_pb2_grpc,
    admin_pb2_grpc,
    api_pb2_grpc,
    auth_pb2_grpc,
    blocking_pb2_grpc,
    bugs_pb2_grpc,
    communities_pb2_grpc,
    conversations_pb2_grpc,
    discussions_pb2_grpc,
    donations_pb2_grpc,
    events_pb2_grpc,
    groups_pb2_grpc,
    jail_pb2_grpc,
    media_pb2_grpc,
    pages_pb2_grpc,
    references_pb2_grpc,
    requests_pb2_grpc,
    resources_pb2_grpc,
    search_pb2_grpc,
    threads_pb2_grpc,
)

# servicers not usable through client:
# * gis
# * stripe


def get_all_stubs(channel):
    return {
        "account": account_pb2_grpc.AccountStub(channel),
        "admin": admin_pb2_grpc.AdminStub(channel),
        "api": api_pb2_grpc.APIStub(channel),
        "auth": auth_pb2_grpc.AuthStub(channel),
        "blocking": blocking_pb2_grpc.BlockingStub(channel),
        "bugs": bugs_pb2_grpc.BugsStub(channel),
        "communities": communities_pb2_grpc.CommunitiesStub(channel),
        "conversations": conversations_pb2_grpc.ConversationsStub(channel),
        "discussions": discussions_pb2_grpc.DiscussionsStub(channel),
        "donations": donations_pb2_grpc.DonationsStub(channel),
        "events": events_pb2_grpc.EventsStub(channel),
        "groups": groups_pb2_grpc.GroupsStub(channel),
        "jail": jail_pb2_grpc.JailStub(channel),
        "media": media_pb2_grpc.MediaStub(channel),
        "pages": pages_pb2_grpc.PagesStub(channel),
        "references": references_pb2_grpc.ReferencesStub(channel),
        "requests": requests_pb2_grpc.RequestsStub(channel),
        "resources": resources_pb2_grpc.ResourcesStub(channel),
        "search": search_pb2_grpc.SearchStub(channel),
        "threads": threads_pb2_grpc.ThreadsStub(channel),
    }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notifications.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13notifications.proto\x12\x1aorg.couchers.notifications\x1a\x11\x61nnotations.proto\"\x1c\n\x1aGetNotificationSettingsReq\"?\n\x1aGetNotificationSettingsRes\x12!\n\x19new_notifications_enabled\x18\x01 \x01(\x08\">\n\x1aSetNotificationSettingsReq\x12 \n\x18\x65nable_new_notifications\x18\x01 \x01(\x08\"\x1c\n\x1aSetNotificationSettingsRes2\xad\x02\n\rNotifications\x12\x89\x01\n\x17GetNotificationSettings\x12\x36.org.couchers.notifications.GetNotificationSettingsReq\x1a\x36.org.couchers.notifications.GetNotificationSettingsRes\x12\x89\x01\n\x17SetNotificationSettings\x12\x36.org.couchers.notifications.SetNotificationSettingsReq\x1a\x36.org.couchers.notifications.SetNotificationSettingsRes\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NOTIFICATIONS']._loaded_options = None
  _globals['_NOTIFICATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_start=70
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_end=98
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_start=100
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_end=163
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_start=165
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_end=227
  _globals['_SETNOTIFICATIONSETTINGSRES']._serialized_start=229
  _globals['_SETNOTIFICATIONSETTINGSRES']._serialized_end=257
  _globals['_NOTIFICATIONS']._serialized_start=260
  _globals['_NOTIFICATIONS']._serialized_end=561
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stripe.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cstripe.proto\x12\x13org.couchers.stripe\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x11\x61nnotations.proto2^\n\x06Stripe\x12N\n\x07Webhook\x12\x14.google.api.HttpBody\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/stripe/webhook\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stripe_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STRIPE']._loaded_options = None
  _globals['_STRIPE']._serialized_options = b'\210\265\030\001'
  _globals['_STRIPE'].methods_by_name['Webhook']._loaded_options = None
  _globals['_STRIPE'].methods_by_name['Webhook']._serialized_options = b'\202\323\344\223\002\021\"\017/stripe/webhook'
  _globals['_STRIPE']._serialized_start=113
  _globals['_STRIPE']._serialized_end=207
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pages.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bpages.proto\x12\x16org.couchers.api.pages\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"&\n\nCoordinate\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\"\xb0\x04\n\x04Page\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .org.couchers.api.pages.PageType\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_edited\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13last_editor_user_id\x18\x06 \x01(\x03\x12\x17\n\x0f\x63reator_user_id\x18\x07 \x01(\x03\x12\x17\n\rowner_user_id\x18\x08 \x01(\x03H\x00\x12\x1c\n\x12owner_community_id\x18\x11 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\t \x01(\x03H\x00\x12\x30\n\x06thread\x18\x14 \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\r\n\x05title\x18\x0b \x01(\t\x12\x0f\n\x07\x63ontent\x18\x0c \x01(\t\x12\x11\n\tphoto_url\x18\x13 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\r \x01(\t\x12\x34\n\x08location\x18\x0e \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\x12\x17\n\x0f\x65\x64itor_user_ids\x18\x0f \x03(\x03\x12\x10\n\x08\x63\x61n_edit\x18\x10 \x01(\x08\x12\x14\n\x0c\x63\x61n_moderate\x18\x12 \x01(\x08\x42\x07\n\x05owner\"\x8a\x01\n\x0e\x43reatePlaceReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x05 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x34\n\x08location\x18\x04 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"\xa7\x01\n\x0e\x43reateGuideReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x06 \x01(\t\x12\x1b\n\x13parent_community_id\x18\x03 \x01(\x03\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"\x1d\n\nGetPageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\"\x92\x02\n\rUpdatePageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12+\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tphoto_key\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"o\n\x0fTransferPageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12 \n\x16new_owner_community_id\x18\x03 \x01(\x03H\x00\x12\x1c\n\x12new_owner_group_id\x18\x02 \x01(\x03H\x00\x42\x0b\n\tnew_owner\"K\n\x11ListUserPlacesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Z\n\x11ListUserPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"K\n\x11ListUserGuidesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Z\n\x11ListUserGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*M\n\x08PageType\x12\x13\n\x0fPAGE_TYPE_PLACE\x10\x00\x12\x13\n\x0fPAGE_TYPE_GUIDE\x10\x01\x12\x17\n\x13PAGE_TYPE_MAIN_PAGE\x10\x02\x32\x8c\x05\n\x05Pages\x12U\n\x0b\x43reatePlace\x12&.org.couchers.api.pages.CreatePlaceReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12U\n\x0b\x43reateGuide\x12&.org.couchers.api.pages.CreateGuideReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12M\n\x07GetPage\x12\".org.couchers.api.pages.GetPageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12S\n\nUpdatePage\x12%.org.couchers.api.pages.UpdatePageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12W\n\x0cTransferPage\x12\'.org.couchers.api.pages.TransferPageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12h\n\x0eListUserPlaces\x12).org.couchers.api.pages.ListUserPlacesReq\x1a).org.couchers.api.pages.ListUserPlacesRes\"\x00\x12h\n\x0eListUserGuides\x12).org.couchers.api.pages.ListUserGuidesReq\x1a).org.couchers.api.pages.ListUserGuidesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PAGES']._loaded_options = None
  _globals['_PAGES']._serialized_options = b'\210\265\030\003'
  _globals['_PAGETYPE']._serialized_start=1811
  _globals['_PAGETYPE']._serialized_end=1888
  _globals['_COORDINATE']._serialized_start=138
  _globals['_COORDINATE']._serialized_end=176
  _globals['_PAGE']._serialized_start=179
  _globals['_PAGE']._serialized_end=739
  _globals['_CREATEPLACEREQ']._serialized_start=742
  _globals['_CREATEPLACEREQ']._serialized_end=880
  _globals['_CREATEGUIDEREQ']._serialized_start=883
  _globals['_CREATEGUIDEREQ']._serialized_end=1050
  _globals['_GETPAGEREQ']._serialized_start=1052
  _globals['_GETPAGEREQ']._serialized_end=1081
  _globals['_UPDATEPAGEREQ']._serialized_start=1084
  _globals['_UPDATEPAGEREQ']._serialized_end=1358
  _globals['_TRANSFERPAGEREQ']._serialized_start=1360
  _globals['_TRANSFERPAGEREQ']._serialized_end=1471
  _globals['_LISTUSERPLACESREQ']._serialized_start=1473
  _globals['_LISTUSERPLACESREQ']._serialized_end=1548
  _globals['_LISTUSERPLACESRES']._serialized_start=1550
  _globals['_LISTUSERPLACESRES']._serialized_end=1640
  _globals['_LISTUSERGUIDESREQ']._serialized_start=1642
  _globals['_LISTUSERGUIDESREQ']._serialized_end=1717
  _globals['_LISTUSERGUIDESRES']._serialized_start=1719
  _globals['_LISTUSERGUIDESRES']._serialized_end=1809
  _globals['_PAGES']._serialized_start=1891
  _globals['_PAGES']._serialized_end=2543
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"\x83\x01\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"\x1a\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"%\n\x15RecoverDeletedUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x81\x01\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t\"\x1b\n\x0bGetChatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0bGetChatsRes\x12\x10\n\x08response\x18\x02 \x01(\t2\xc7\x06\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x62\n\x12RecoverDeletedUser\x12).org.couchers.admin.RecoverDeletedUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12\x64\n\x0f\x43reateCommunity\x12&.org.couchers.admin.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12N\n\x08GetChats\x12\x1f.org.couchers.admin.GetChatsReq\x1a\x1f.org.couchers.admin.GetChatsRes\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\210\265\030\004'
  _globals['_USERDETAILS']._serialized_start=74
  _globals['_USERDETAILS']._serialized_end=205
  _globals['_GETUSERDETAILSREQ']._serialized_start=207
  _globals['_GETUSERDETAILSREQ']._serialized_end=240
  _globals['_CHANGEUSERGENDERREQ']._serialized_start=242
  _globals['_CHANGEUSERGENDERREQ']._serialized_end=293
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_start=295
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_end=352
  _globals['_BANUSERREQ']._serialized_start=354
  _globals['_BANUSERREQ']._serialized_end=380
  _globals['_DELETEUSERREQ']._serialized_start=382
  _globals['_DELETEUSERREQ']._serialized_end=411
  _globals['_RECOVERDELETEDUSERREQ']._serialized_start=413
  _globals['_RECOVERDELETEDUSERREQ']._serialized_end=450
  _globals['_CREATEAPIKEYREQ']._serialized_start=452
  _globals['_CREATEAPIKEYREQ']._serialized_end=483
  _globals['_CREATEAPIKEYRES']._serialized_start=485
  _globals['_CREATEAPIKEYRES']._serialized_end=502
  _globals['_CREATECOMMUNITYREQ']._serialized_start=505
  _globals['_CREATECOMMUNITYREQ']._serialized_end=634
  _globals['_GETCHATSREQ']._serialized_start=636
  _globals['_GETCHATSREQ']._serialized_end=663
  _globals['_GETCHATSRES']._serialized_start=665
  _globals['_GETCHATSRES']._serialized_end=696
  _globals['_ADMIN']._serialized_start=699
  _globals['_ADMIN']._serialized_end=1538
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bugs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbugs.proto\x12\x11org.couchers.bugs\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x81\x01\n\x0cReportBugReq\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07results\x18\x04 \x01(\t\x12\x18\n\x10\x66rontend_version\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0c\n\x04page\x18\x07 \x01(\t\"/\n\x0cReportBugRes\x12\x0e\n\x06\x62ug_id\x18\x02 \x01(\t\x12\x0f\n\x07\x62ug_url\x18\x03 \x01(\t2\xb2\x01\n\x04\x42ugs\x12S\n\x07Version\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.bugs.VersionInfo\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/version\x12O\n\tReportBug\x12\x1f.org.couchers.bugs.ReportBugReq\x1a\x1f.org.couchers.bugs.ReportBugRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bugs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUGS']._loaded_options = None
  _globals['_BUGS']._serialized_options = b'\210\265\030\001'
  _globals['_BUGS'].methods_by_name['Version']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Version']._serialized_options = b'\202\323\344\223\002\n\022\010/version'
  _globals['_VERSIONINFO']._serialized_start=111
  _globals['_VERSIONINFO']._serialized_end=141
  _globals['_REPORTBUGREQ']._serialized_start=144
  _globals['_REPORTBUGREQ']._serialized_end=273
  _globals['_REPORTBUGRES']._serialized_start=275
  _globals['_REPORTBUGRES']._serialized_end=322
  _globals['_BUGS']._serialized_start=325
  _globals['_BUGS']._serialized_end=503
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import auth_pb2 as auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\raccount.proto\x12\x18org.couchers.api.account\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\nauth.proto\"\x99\x02\n\x11GetAccountInfoRes\x12M\n\x0clogin_method\x18\x01 \x01(\x0e\x32\x37.org.couchers.api.account.GetAccountInfoRes.LoginMethod\x12\x14\n\x0chas_password\x18\x02 \x01(\x08\x12\x10\n\x08username\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x18\n\x10profile_complete\x18\x04 \x01(\x08\x12\r\n\x05phone\x18\x08 \x01(\t\x12\x16\n\x0ephone_verified\x18\t \x01(\x08\x12\x10\n\x08timezone\x18\x06 \x01(\t\"+\n\x0bLoginMethod\x12\x0e\n\nMAGIC_LINK\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\"\x87\x01\n\x11\x43hangePasswordReq\x12\x38\n\x0cold_password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\x12\x38\n\x0cnew_password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\"Y\n\x0e\x43hangeEmailReq\x12\x34\n\x08password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\"<\n\x19GetContributorFormInfoRes\x12\x1f\n\x17\x66illed_contributor_form\x18\x01 \x01(\x08\"V\n\x16\x46illContributorFormReq\x12<\n\x10\x63ontributor_form\x18\x01 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\"\x1f\n\x0e\x43hangePhoneReq\x12\r\n\x05phone\x18\x01 \x01(\t\"%\n\x0eVerifyPhoneReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"3\n\x10\x44\x65leteAccountReq\x12\x0f\n\x07\x63onfirm\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t2\xdd\x05\n\x07\x41\x63\x63ount\x12W\n\x0eGetAccountInfo\x12\x16.google.protobuf.Empty\x1a+.org.couchers.api.account.GetAccountInfoRes\"\x00\x12W\n\x0e\x43hangePassword\x12+.org.couchers.api.account.ChangePasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangeEmail\x12(.org.couchers.api.account.ChangeEmailReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x16GetContributorFormInfo\x12\x16.google.protobuf.Empty\x1a\x33.org.couchers.api.account.GetContributorFormInfoRes\"\x00\x12\x61\n\x13\x46illContributorForm\x12\x30.org.couchers.api.account.FillContributorFormReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangePhone\x12(.org.couchers.api.account.ChangePhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0bVerifyPhone\x12(.org.couchers.api.account.VerifyPhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\rDeleteAccount\x12*.org.couchers.api.account.DeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['old_password']._loaded_options = None
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['old_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEEMAILREQ'].fields_by_name['password']._loaded_options = None
  _globals['_CHANGEEMAILREQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._loaded_options = None
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._serialized_options = b'\200\265\030\001'
  _globals['_ACCOUNT']._loaded_options = None
  _globals['_ACCOUNT']._serialized_options = b'\210\265\030\003'
  _globals['_GETACCOUNTINFORES']._serialized_start=136
  _globals['_GETACCOUNTINFORES']._serialized_end=417
  _globals['_GETACCOUNTINFORES_LOGINMETHOD']._serialized_start=374
  _globals['_GETACCOUNTINFORES_LOGINMETHOD']._serialized_end=417
  _globals['_CHANGEPASSWORDREQ']._serialized_start=420
  _globals['_CHANGEPASSWORDREQ']._serialized_end=555
  _globals['_CHANGEEMAILREQ']._serialized_start=557
  _globals['_CHANGEEMAILREQ']._serialized_end=646
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_start=648
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_end=708
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_start=710
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_end=796
  _globals['_CHANGEPHONEREQ']._serialized_start=798
  _globals['_CHANGEPHONEREQ']._serialized_end=829
  _globals['_VERIFYPHONEREQ']._serialized_start=831
  _globals['_VERIFYPHONEREQ']._serialized_end=868
  _globals['_DELETEACCOUNTREQ']._serialized_start=870
  _globals['_DELETEACCOUNTREQ']._serialized_end=921
  _globals['_ACCOUNT']._serialized_start=924
  _globals['_ACCOUNT']._serialized_end=1657
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgis.proto\x12\x11org.couchers.json\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto2\xe3\x02\n\x03GIS\x12P\n\x08GetUsers\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/geojson/users\x12\\\n\x0eGetCommunities\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/geojson/communities\x12R\n\tGetPlaces\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/places\x12R\n\tGetGuides\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/guides\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GIS']._loaded_options = None
  _globals['_GIS']._serialized_options = b'\210\265\030\003'
  _globals['_GIS'].methods_by_name['GetUsers']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetUsers']._serialized_options = b'\202\323\344\223\002\020\022\016/geojson/users'
  _globals['_GIS'].methods_by_name['GetCommunities']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetCommunities']._serialized_options = b'\202\323\344\223\002\026\022\024/geojson/communities'
  _globals['_GIS'].methods_by_name['GetPlaces']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetPlaces']._serialized_options = b'\202\323\344\223\002\021\022\017/geojson/places'
  _globals['_GIS'].methods_by_name['GetGuides']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetGuides']._serialized_options = b'\202\323\344\223\002\021\022\017/geojson/guides'
  _globals['_GIS']._serialized_start=138
  _globals['_GIS']._serialized_end=493
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2
from . import communities_pb2 as communities__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csearch.proto\x12\x17org.couchers.api.search\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\x1a\x11\x63ommunities.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\"0\n\x04\x41rea\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0e\n\x06radius\x18\x03 \x01(\x01\"\xe9\x01\n\tSearchReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x15\n\rinclude_users\x18\x04 \x01(\x08\x12\x1b\n\x13include_communities\x18\x05 \x01(\x08\x12\x16\n\x0einclude_groups\x18\x06 \x01(\x08\x12\x16\n\x0einclude_places\x18\x07 \x01(\x08\x12\x16\n\x0einclude_guides\x18\x08 \x01(\x08\x12\x16\n\x0einclude_events\x18\n \x01(\x08\x12\x12\n\ntitle_only\x18\r \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xdc\x02\n\x06Result\x12\x0c\n\x04rank\x18\x01 \x01(\x01\x12\x0f\n\x07snippet\x18\x02 \x01(\t\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.UserH\x00\x12<\n\tcommunity\x18\x04 \x01(\x0b\x32\'.org.couchers.api.communities.CommunityH\x00\x12/\n\x05group\x18\x05 \x01(\x0b\x32\x1e.org.couchers.api.groups.GroupH\x00\x12-\n\x05place\x18\x06 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12-\n\x05guide\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12/\n\x05\x65vent\x18\x08 \x01(\x0b\x32\x1e.org.couchers.api.events.EventH\x00\x42\x08\n\x06result\"V\n\tSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc7\n\n\rUserSearchReq\x12+\n\x05query\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x17\n\x0fquery_name_only\x18\x1e \x01(\x08\x12/\n\x0blast_active\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0esearch_in_area\x18\x1c \x01(\x0b\x32\x1d.org.couchers.api.search.AreaH\x00\x12 \n\x16search_in_community_id\x18\x1d \x01(\x03H\x00\x12\x43\n\x15hosting_status_filter\x18\x05 \x03(\x0e\x32$.org.couchers.api.core.HostingStatus\x12G\n\x17smoking_location_filter\x18\x06 \x03(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12O\n\x1bsleeping_arrangement_filter\x18\x07 \x03(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x45\n\x16parking_details_filter\x18\x08 \x03(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12,\n\x06gender\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06guests\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14only_with_references\x18\x0c \x01(\x08\x12/\n\x0blast_minute\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_pets\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_pets\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_kids\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_kids\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ehas_housemates\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15wheelchair_accessible\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0esmokes_at_home\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x64rinking_allowed\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x64rinks_at_home\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07parking\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncamping_ok\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11profile_completed\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\tB\x0b\n\tsearch_in\"Z\n\rUserSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc2\x01\n\x06Search\x12R\n\x06Search\x12\".org.couchers.api.search.SearchReq\x1a\".org.couchers.api.search.SearchRes\"\x00\x12^\n\nUserSearch\x12&.org.couchers.api.search.UserSearchReq\x1a&.org.couchers.api.search.UserSearchRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SEARCH']._loaded_options = None
  _globals['_SEARCH']._serialized_options = b'\210\265\030\003'
  _globals['_AREA']._serialized_start=196
  _globals['_AREA']._serialized_end=244
  _globals['_SEARCHREQ']._serialized_start=247
  _globals['_SEARCHREQ']._serialized_end=480
  _globals['_RESULT']._serialized_start=483
  _globals['_RESULT']._serialized_end=831
  _globals['_SEARCHRES']._serialized_start=833
  _globals['_SEARCHRES']._serialized_end=919
  _globals['_USERSEARCHREQ']._serialized_start=922
  _globals['_USERSEARCHREQ']._serialized_end=2273
  _globals['_USERSEARCHRES']._serialized_start=2275
  _globals['_USERSEARCHRES']._serialized_end=2365
  _globals['_SEARCH']._serialized_start=2368
  _globals['_SEARCH']._serialized_end=2562
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import auth_pb2 as auth__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AuthStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SignupFlow = channel.unary_unary(
                '/org.couchers.auth.Auth/SignupFlow',
                request_serializer=auth__pb2.SignupFlowReq.SerializeToString,
                response_deserializer=auth__pb2.SignupFlowRes.FromString,
                )
        self.UsernameValid = channel.unary_unary(
                '/org.couchers.auth.Auth/UsernameValid',
                request_serializer=auth__pb2.UsernameValidReq.SerializeToString,
                response_deserializer=auth__pb2.UsernameValidRes.FromString,
                )
        self.Login = channel.unary_unary(
                '/org.couchers.auth.Auth/Login',
                request_serializer=auth__pb2.LoginReq.SerializeToString,
                response_deserializer=auth__pb2.LoginRes.FromString,
                )
        self.CompleteTokenLogin = channel.unary_unary(
                '/org.couchers.auth.Auth/CompleteTokenLogin',
                request_serializer=auth__pb2.CompleteTokenLoginReq.SerializeToString,
                response_deserializer=auth__pb2.AuthRes.FromString,
                )
        self.Authenticate = channel.unary_unary(
                '/org.couchers.auth.Auth/Authenticate',
                request_serializer=auth__pb2.AuthReq.SerializeToString,
                response_deserializer=auth__pb2.AuthRes.FromString,
                )
        self.Deauthenticate = channel.unary_unary(
                '/org.couchers.auth.Auth/Deauthenticate',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ResetPassword = channel.unary_unary(
                '/org.couchers.auth.Auth/ResetPassword',
                request_serializer=auth__pb2.ResetPasswordReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CompletePasswordReset = channel.unary_unary(
                '/org.couchers.auth.Auth/CompletePasswordReset',
                request_serializer=auth__pb2.CompletePasswordResetReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ConfirmChangeEmail = channel.unary_unary(
                '/org.couchers.auth.Auth/ConfirmChangeEmail',
                request_serializer=auth__pb2.ConfirmChangeEmailReq.SerializeToString,
                response_deserializer=auth__pb2.ConfirmChangeEmailRes.FromString,
                )
        self.ConfirmDeleteAccount = channel.unary_unary(
                '/org.couchers.auth.Auth/ConfirmDeleteAccount',
                request_serializer=auth__pb2.ConfirmDeleteAccountReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RecoverAccount = channel.unary_unary(
                '/org.couchers.auth.Auth/RecoverAccount',
                request_serializer=auth__pb2.RecoverAccountReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Unsubscribe = channel.unary_unary(
                '/org.couchers.auth.Auth/Unsubscribe',
                request_serializer=auth__pb2.UnsubscribeReq.SerializeToString,
                response_deserializer=auth__pb2.UnsubscribeRes.FromString,
                )


class AuthServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SignupFlow(self, request, context):
        """
        Authentication API

        This API facilitates authentication actions: signup and signin. Users need to use this before logging in, so you don't
        need to be authorized to use it.

        The signup flow is as follows:
        A user enters their email and submits a form, which fires off a Signup call
        Signup validates the email isn't in the database yet, creates a signup_token, and emails it to the email address
        User clicks on the signup link, which brings them onto the signup completion form
        When this form loads, the app queries SignupTokenInfo for the email address associated to that login token to
        display in the UI
        User chooses a username (possibly querying UsernameValid to check possibly usernames) and fills in other basic
        information
        User submits the signup completion form, which validates this input, creates the user and logs them in, returns a
        session token (signup token is invalidated)

        The login flow is as follows:
        The user enters an identifier field and submits the form
        The backend finds the user based on either username/user id/email address
        If that user _does not_ have a password, we email a one-click signin token and return SENT_LOGIN_EMAIL
        If that user _does not_ have a password, they click that link and the app logs them in through a
        CompleteTokenLoginReq (login token is invalidated)
        If that user _does_ have a password, the app asks for that password, and submits an Authenticate Call to log the
        user in

        Signup and login tokens expire after some time, and once used cannot be reused.

        There can be multiple signup requests simultaneously with the same email address. Email address uniqueness is checked
        once when creating the signup request, and again when creating the user.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UsernameValid(self, request, context):
        """Check whether the username is valid and available
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """First step of login flow.

        The user is searched for using their id, username, or email.

        If the user does not exist or has been deleted, throws a NOT_FOUND rpc error.

        If the user has a password, returns NEED_PASSWORD.

        If the user exists but does not have a password, generates a login token, send it in the email and returns
        SENT_LOGIN_EMAIL.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteTokenLogin(self, request, context):
        """Complete a login after receiving an email with a login token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Authenticate(self, request, context):
        """Auth a user with username + password
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deauthenticate(self, request, context):
        """Invalidate a session, deauthing a user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetPassword(self, request, context):
        """Sends a forgot password email to the given user if the user exists, returns no output (so you can't go around
        guessing email addresses)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompletePasswordReset(self, request, context):
        """Triggered when the user goes to the link sent in the forgot password email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmChangeEmail(self, request, context):
        """Triggered when the user goes to the link sent in the either email_changed_confirmation_*_email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmDeleteAccount(self, request, context):
        """Confirms deletion of a user using a token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecoverAccount(self, request, context):
        """Recovers a recently deleted account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unsubscribe(self, request, context):
        """Handle an unsubscribe action from an email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SignupFlow': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupFlow,
                    request_deserializer=auth__pb2.SignupFlowReq.FromString,
                    response_serializer=auth__pb2.SignupFlowRes.SerializeToString,
            ),
            'UsernameValid': grpc.unary_unary_rpc_method_handler(
                    servicer.UsernameValid,
                    request_deserializer=auth__pb2.UsernameValidReq.FromString,
                    response_serializer=auth__pb2.UsernameValidRes.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=auth__pb2.LoginReq.FromString,
                    response_serializer=auth__pb2.LoginRes.SerializeToString,
            ),
            'CompleteTokenLogin': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteTokenLogin,
                    request_deserializer=auth__pb2.CompleteTokenLoginReq.FromString,
                    response_serializer=auth__pb2.AuthRes.SerializeToString,
            ),
            'Authenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Authenticate,
                    request_deserializer=auth__pb2.AuthReq.FromString,
                    response_serializer=auth__pb2.AuthRes.SerializeToString,
            ),
            'Deauthenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deauthenticate,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ResetPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetPassword,
                    request_deserializer=auth__pb2.ResetPasswordReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CompletePasswordReset': grpc.unary_unary_rpc_method_handler(
                    servicer.CompletePasswordReset,
                    request_deserializer=auth__pb2.CompletePasswordResetReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ConfirmChangeEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmChangeEmail,
                    request_deserializer=auth__pb2.ConfirmChangeEmailReq.FromString,
                    response_serializer=auth__pb2.ConfirmChangeEmailRes.SerializeToString,
            ),
            'ConfirmDeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmDeleteAccount,
                    request_deserializer=auth__pb2.ConfirmDeleteAccountReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RecoverAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.RecoverAccount,
                    request_deserializer=auth__pb2.RecoverAccountReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Unsubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Unsubscribe,
                    request_deserializer=auth__pb2.UnsubscribeReq.FromString,
                    response_serializer=auth__pb2.UnsubscribeRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.auth.Auth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Auth(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SignupFlow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/SignupFlow',
            auth__pb2.SignupFlowReq.SerializeToString,
            auth__pb2.SignupFlowRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UsernameValid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/UsernameValid',
            auth__pb2.UsernameValidReq.SerializeToString,
            auth__pb2.UsernameValidRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Login',
            auth__pb2.LoginReq.SerializeToString,
            auth__pb2.LoginRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteTokenLogin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/CompleteTokenLogin',
            auth__pb2.CompleteTokenLoginReq.SerializeToString,
            auth__pb2.AuthRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Authenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Authenticate',
            auth__pb2.AuthReq.SerializeToString,
            auth__pb2.AuthRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deauthenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Deauthenticate',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/ResetPassword',
            auth__pb2.ResetPasswordReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompletePasswordReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/CompletePasswordReset',
            auth__pb2.CompletePasswordResetReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmChangeEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/ConfirmChangeEmail',
            auth__pb2.ConfirmChangeEmailReq.SerializeToString,
            auth__pb2.ConfirmChangeEmailRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmDeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/ConfirmDeleteAccount',
            auth__pb2.ConfirmDeleteAccountReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecoverAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/RecoverAccount',
            auth__pb2.RecoverAccountReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unsubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.auth.Auth/Unsubscribe',
            auth__pb2.UnsubscribeReq.SerializeToString,
            auth__pb2.UnsubscribeRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: references.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10references.proto\x12\x1borg.couchers.api.references\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\xe8\x01\n\tReference\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x66rom_user_id\x18\x02 \x01(\x03\x12\x12\n\nto_user_id\x18\x03 \x01(\x03\x12\x42\n\x0ereference_type\x18\x04 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x30\n\x0cwritten_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fhost_request_id\x18\x07 \x01(\x03\"\xaf\x01\n\x11ListReferencesReq\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\x12I\n\x15reference_type_filter\x18\x03 \x03(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x11\n\tpage_size\x18\x04 \x01(\r\x12\x12\n\npage_token\x18\x05 \x01(\t\"h\n\x11ListReferencesRes\x12:\n\nreferences\x18\x01 \x03(\x0b\x32&.org.couchers.api.references.Reference\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"z\n\x17WriteFriendReferenceReq\x12\x12\n\nto_user_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x14\n\x0cprivate_text\x18\x05 \x01(\t\x12\x17\n\x0fwas_appropriate\x18\x03 \x01(\x08\x12\x0e\n\x06rating\x18\x04 \x01(\x01\"\x84\x01\n\x1cWriteHostRequestReferenceReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x14\n\x0cprivate_text\x18\x05 \x01(\t\x12\x17\n\x0fwas_appropriate\x18\x03 \x01(\x08\x12\x0e\n\x06rating\x18\x04 \x01(\x01\"1\n\x1b\x41vailableWriteReferencesReq\x12\x12\n\nto_user_id\x18\x01 \x01(\x03\"\xac\x01\n\x1b\x41vailableWriteReferenceType\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x42\n\x0ereference_type\x18\x02 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x30\n\x0ctime_expires\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9f\x01\n\x1b\x41vailableWriteReferencesRes\x12\"\n\x1a\x63\x61n_write_friend_reference\x18\x01 \x01(\x08\x12\\\n\x1a\x61vailable_write_references\x18\x02 \x03(\x0b\x32\x38.org.couchers.api.references.AvailableWriteReferenceType\"w\n\x1fListPendingReferencesToWriteRes\x12T\n\x12pending_references\x18\x01 \x03(\x0b\x32\x38.org.couchers.api.references.AvailableWriteReferenceType*`\n\rReferenceType\x12\x19\n\x15REFERENCE_TYPE_FRIEND\x10\x00\x12\x19\n\x15REFERENCE_TYPE_SURFED\x10\x01\x12\x19\n\x15REFERENCE_TYPE_HOSTED\x10\x02\x32\x8c\x05\n\nReferences\x12r\n\x0eListReferences\x12..org.couchers.api.references.ListReferencesReq\x1a..org.couchers.api.references.ListReferencesRes\"\x00\x12v\n\x14WriteFriendReference\x12\x34.org.couchers.api.references.WriteFriendReferenceReq\x1a&.org.couchers.api.references.Reference\"\x00\x12\x80\x01\n\x19WriteHostRequestReference\x12\x39.org.couchers.api.references.WriteHostRequestReferenceReq\x1a&.org.couchers.api.references.Reference\"\x00\x12\x90\x01\n\x18\x41vailableWriteReferences\x12\x38.org.couchers.api.references.AvailableWriteReferencesReq\x1a\x38.org.couchers.api.references.AvailableWriteReferencesRes\"\x00\x12v\n\x1cListPendingReferencesToWrite\x12\x16.google.protobuf.Empty\x1a<.org.couchers.api.references.ListPendingReferencesToWriteRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'references_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REFERENCES']._loaded_options = None
  _globals['_REFERENCES']._serialized_options = b'\210\265\030\003'
  _globals['_REFERENCETYPE']._serialized_start=1417
  _globals['_REFERENCETYPE']._serialized_end=1513
  _globals['_REFERENCE']._serialized_start=131
  _globals['_REFERENCE']._serialized_end=363
  _globals['_LISTREFERENCESREQ']._serialized_start=366
  _globals['_LISTREFERENCESREQ']._serialized_end=541
  _globals['_LISTREFERENCESRES']._serialized_start=543
  _globals['_LISTREFERENCESRES']._serialized_end=647
  _globals['_WRITEFRIENDREFERENCEREQ']._serialized_start=649
  _globals['_WRITEFRIENDREFERENCEREQ']._serialized_end=771
  _globals['_WRITEHOSTREQUESTREFERENCEREQ']._serialized_start=774
  _globals['_WRITEHOSTREQUESTREFERENCEREQ']._serialized_end=906
  _globals['_AVAILABLEWRITEREFERENCESREQ']._serialized_start=908
  _globals['_AVAILABLEWRITEREFERENCESREQ']._serialized_end=957
  _globals['_AVAILABLEWRITEREFERENCETYPE']._serialized_start=960
  _globals['_AVAILABLEWRITEREFERENCETYPE']._serialized_end=1132
  _globals['_AVAILABLEWRITEREFERENCESRES']._serialized_start=1135
  _globals['_AVAILABLEWRITEREFERENCESRES']._serialized_end=1294
  _globals['_LISTPENDINGREFERENCESTOWRITERES']._serialized_start=1296
  _globals['_LISTPENDINGREFERENCESTOWRITERES']._serialized_end=1415
  _globals['_REFERENCES']._serialized_start=1516
  _globals['_REFERENCES']._serialized_end=2168
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import account_pb2 as account__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AccountStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountInfo = channel.unary_unary(
                '/org.couchers.api.account.Account/GetAccountInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.GetAccountInfoRes.FromString,
                )
        self.ChangePassword = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangePassword',
                request_serializer=account__pb2.ChangePasswordReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChangeEmail = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangeEmail',
                request_serializer=account__pb2.ChangeEmailReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetContributorFormInfo = channel.unary_unary(
                '/org.couchers.api.account.Account/GetContributorFormInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.GetContributorFormInfoRes.FromString,
                )
        self.FillContributorForm = channel.unary_unary(
                '/org.couchers.api.account.Account/FillContributorForm',
                request_serializer=account__pb2.FillContributorFormReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChangePhone = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangePhone',
                request_serializer=account__pb2.ChangePhoneReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.VerifyPhone = channel.unary_unary(
                '/org.couchers.api.account.Account/VerifyPhone',
                request_serializer=account__pb2.VerifyPhoneReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAccount = channel.unary_unary(
                '/org.couchers.api.account.Account/DeleteAccount',
                request_serializer=account__pb2.DeleteAccountReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class AccountServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAccountInfo(self, request, context):
        """account management APIs
        Get information about the user's account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePassword(self, request, context):
        """Change, set, or unset the user's password
        we will send and an email to the user saying their password was changed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeEmail(self, request, context):
        """Change the user's email address
        If user has password, we will send a notification email to the old email, and confirmation email to the new email
        If not, we will send a confirmation email to both emails
        Raises INVALID_ARGUMENT if password is too small, too large, insecure, wrong or not supplied.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContributorFormInfo(self, request, context):
        """Returns info related to filling out the contributor form
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FillContributorForm(self, request, context):
        """Fill the contributor form; this can be done multiple times
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePhone(self, request, context):
        """Set/Change/Remove phone number. An verification sms with a 6-digit code will be sent out,
        And returned in a call to in VerifyPhone() to complete the phone number change.
        An INVALID_ARGUMENT is returned if the phone number is not formatted according to E.164.
        A RESOURCE_EXHAUSTED error code indicates that you have done too many changes lately.
        An UNIMPLEMENTED error code indicates that sms to your operator is not supported.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyPhone(self, request, context):
        """Enter the code you got in the sms. Other accounts using the same phone number will
        lose their verification status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccount(self, request, context):
        """Sends email with confirmation link containing token to delete account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.GetAccountInfoRes.SerializeToString,
            ),
            'ChangePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePassword,
                    request_deserializer=account__pb2.ChangePasswordReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChangeEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeEmail,
                    request_deserializer=account__pb2.ChangeEmailReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetContributorFormInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContributorFormInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.GetContributorFormInfoRes.SerializeToString,
            ),
            'FillContributorForm': grpc.unary_unary_rpc_method_handler(
                    servicer.FillContributorForm,
                    request_deserializer=account__pb2.FillContributorFormReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChangePhone': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePhone,
                    request_deserializer=account__pb2.ChangePhoneReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'VerifyPhone': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyPhone,
                    request_deserializer=account__pb2.VerifyPhoneReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccount,
                    request_deserializer=account__pb2.DeleteAccountReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.account.Account', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Account(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAccountInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetAccountInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.GetAccountInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangePassword',
            account__pb2.ChangePasswordReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangeEmail',
            account__pb2.ChangeEmailReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContributorFormInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetContributorFormInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.GetContributorFormInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FillContributorForm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/FillContributorForm',
            account__pb2.FillContributorFormReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePhone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangePhone',
            account__pb2.ChangePhoneReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyPhone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/VerifyPhone',
            account__pb2.VerifyPhoneReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/DeleteAccount',
            account__pb2.DeleteAccountReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import conversations_pb2 as conversations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ConversationsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListGroupChats = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/ListGroupChats',
                request_serializer=conversations__pb2.ListGroupChatsReq.SerializeToString,
                response_deserializer=conversations__pb2.ListGroupChatsRes.FromString,
                )
        self.GetGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/GetGroupChat',
                request_serializer=conversations__pb2.GetGroupChatReq.SerializeToString,
                response_deserializer=conversations__pb2.GroupChat.FromString,
                )
        self.GetDirectMessage = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/GetDirectMessage',
                request_serializer=conversations__pb2.GetDirectMessageReq.SerializeToString,
                response_deserializer=conversations__pb2.GroupChat.FromString,
                )
        self.GetUpdates = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/GetUpdates',
                request_serializer=conversations__pb2.GetUpdatesReq.SerializeToString,
                response_deserializer=conversations__pb2.GetUpdatesRes.FromString,
                )
        self.GetGroupChatMessages = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/GetGroupChatMessages',
                request_serializer=conversations__pb2.GetGroupChatMessagesReq.SerializeToString,
                response_deserializer=conversations__pb2.GetGroupChatMessagesRes.FromString,
                )
        self.MarkLastSeenGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/MarkLastSeenGroupChat',
                request_serializer=conversations__pb2.MarkLastSeenGroupChatReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.MuteGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/MuteGroupChat',
                request_serializer=conversations__pb2.MuteGroupChatReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/CreateGroupChat',
                request_serializer=conversations__pb2.CreateGroupChatReq.SerializeToString,
                response_deserializer=conversations__pb2.GroupChat.FromString,
                )
        self.EditGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/EditGroupChat',
                request_serializer=conversations__pb2.EditGroupChatReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InviteToGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/InviteToGroupChat',
                request_serializer=conversations__pb2.InviteToGroupChatReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.MakeGroupChatAdmin = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/MakeGroupChatAdmin',
                request_serializer=conversations__pb2.MakeGroupChatAdminReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RemoveGroupChatUser = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/RemoveGroupChatUser',
                request_serializer=conversations__pb2.RemoveGroupChatUserReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RemoveGroupChatAdmin = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/RemoveGroupChatAdmin',
                request_serializer=conversations__pb2.RemoveGroupChatAdminReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SendMessage = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/SendMessage',
                request_serializer=conversations__pb2.SendMessageReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.LeaveGroupChat = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/LeaveGroupChat',
                request_serializer=conversations__pb2.LeaveGroupChatReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SearchMessages = channel.unary_unary(
                '/org.couchers.api.conversations.Conversations/SearchMessages',
                request_serializer=conversations__pb2.SearchMessagesReq.SerializeToString,
                response_deserializer=conversations__pb2.SearchMessagesRes.FromString,
                )


class ConversationsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListGroupChats(self, request, context):
        """Retrieves list of group chats (ordered by last message), paginated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupChat(self, request, context):
        """Retrieves group chat info by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDirectMessage(self, request, context):
        """Retrieves group chat info for the unique (if any) direct message with a
        given user

        Raises: NOT_FOUND if there is no such direct message thread
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpdates(self, request, context):
        """Returns all new messages (aka updates) since a given message id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupChatMessages(self, request, context):
        """Retrieves messages in group chat, paginated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkLastSeenGroupChat(self, request, context):
        """Marks the last message that has been seen in this group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MuteGroupChat(self, request, context):
        """Mutes or unmutes a group chat
        when muted, you don't get notifications from that group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGroupChat(self, request, context):
        """Creates a new group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditGroupChat(self, request, context):
        """Modifies group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteToGroupChat(self, request, context):
        """Invite a person to a chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakeGroupChatAdmin(self, request, context):
        """Make a user an admin of a group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveGroupChatUser(self, request, context):
        """Remove a user in a group chat.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveGroupChatAdmin(self, request, context):
        """Remove a user from admin in group chat. TODO: Only original creator can do this
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendMessage(self, request, context):
        """Send a message to a group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LeaveGroupChat(self, request, context):
        """Leave a group chat
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchMessages(self, request, context):
        """Search messages by string
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConversationsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListGroupChats': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGroupChats,
                    request_deserializer=conversations__pb2.ListGroupChatsReq.FromString,
                    response_serializer=conversations__pb2.ListGroupChatsRes.SerializeToString,
            ),
            'GetGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupChat,
                    request_deserializer=conversations__pb2.GetGroupChatReq.FromString,
                    response_serializer=conversations__pb2.GroupChat.SerializeToString,
            ),
            'GetDirectMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDirectMessage,
                    request_deserializer=conversations__pb2.GetDirectMessageReq.FromString,
                    response_serializer=conversations__pb2.GroupChat.SerializeToString,
            ),
            'GetUpdates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpdates,
                    request_deserializer=conversations__pb2.GetUpdatesReq.FromString,
                    response_serializer=conversations__pb2.GetUpdatesRes.SerializeToString,
            ),
            'GetGroupChatMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupChatMessages,
                    request_deserializer=conversations__pb2.GetGroupChatMessagesReq.FromString,
                    response_serializer=conversations__pb2.GetGroupChatMessagesRes.SerializeToString,
            ),
            'MarkLastSeenGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkLastSeenGroupChat,
                    request_deserializer=conversations__pb2.MarkLastSeenGroupChatReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'MuteGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.MuteGroupChat,
                    request_deserializer=conversations__pb2.MuteGroupChatReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroupChat,
                    request_deserializer=conversations__pb2.CreateGroupChatReq.FromString,
                    response_serializer=conversations__pb2.GroupChat.SerializeToString,
            ),
            'EditGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.EditGroupChat,
                    request_deserializer=conversations__pb2.EditGroupChatReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InviteToGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteToGroupChat,
                    request_deserializer=conversations__pb2.InviteToGroupChatReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'MakeGroupChatAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.MakeGroupChatAdmin,
                    request_deserializer=conversations__pb2.MakeGroupChatAdminReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RemoveGroupChatUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveGroupChatUser,
                    request_deserializer=conversations__pb2.RemoveGroupChatUserReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RemoveGroupChatAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveGroupChatAdmin,
                    request_deserializer=conversations__pb2.RemoveGroupChatAdminReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SendMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendMessage,
                    request_deserializer=conversations__pb2.SendMessageReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'LeaveGroupChat': grpc.unary_unary_rpc_method_handler(
                    servicer.LeaveGroupChat,
                    request_deserializer=conversations__pb2.LeaveGroupChatReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SearchMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchMessages,
                    request_deserializer=conversations__pb2.SearchMessagesReq.FromString,
                    response_serializer=conversations__pb2.SearchMessagesRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.conversations.Conversations', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Conversations(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListGroupChats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/ListGroupChats',
            conversations__pb2.ListGroupChatsReq.SerializeToString,
            conversations__pb2.ListGroupChatsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/GetGroupChat',
            conversations__pb2.GetGroupChatReq.SerializeToString,
            conversations__pb2.GroupChat.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDirectMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/GetDirectMessage',
            conversations__pb2.GetDirectMessageReq.SerializeToString,
            conversations__pb2.GroupChat.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUpdates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/GetUpdates',
            conversations__pb2.GetUpdatesReq.SerializeToString,
            conversations__pb2.GetUpdatesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupChatMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/GetGroupChatMessages',
            conversations__pb2.GetGroupChatMessagesReq.SerializeToString,
            conversations__pb2.GetGroupChatMessagesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkLastSeenGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/MarkLastSeenGroupChat',
            conversations__pb2.MarkLastSeenGroupChatReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MuteGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/MuteGroupChat',
            conversations__pb2.MuteGroupChatReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/CreateGroupChat',
            conversations__pb2.CreateGroupChatReq.SerializeToString,
            conversations__pb2.GroupChat.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/EditGroupChat',
            conversations__pb2.EditGroupChatReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteToGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/InviteToGroupChat',
            conversations__pb2.InviteToGroupChatReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MakeGroupChatAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/MakeGroupChatAdmin',
            conversations__pb2.MakeGroupChatAdminReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveGroupChatUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/RemoveGroupChatUser',
            conversations__pb2.RemoveGroupChatUserReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveGroupChatAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/RemoveGroupChatAdmin',
            conversations__pb2.RemoveGroupChatAdminReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/SendMessage',
            conversations__pb2.SendMessageReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LeaveGroupChat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/LeaveGroupChat',
            conversations__pb2.LeaveGroupChatReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.conversations.Conversations/SearchMessages',
            conversations__pb2.SearchMessagesReq.SerializeToString,
            conversations__pb2.SearchMessagesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
